Learn R Programming

spldv (version 0.1.3)

getSummary.bingmm: Get Model Summaries for use with "mtable" for objects of class bingmm

Description

A generic function to collect coefficients and summary statistics from a bingmm object. It is used in mtable

Usage

# S3 method for bingmm
getSummary(obj, alpha = 0.05, ...)

Value

A list with an array with coefficient estimates and a vector containing the model summary statistics.

Arguments

obj

a bingmm object,

alpha

level of the confidence intervals,

...

further arguments,

Details

For more details see package memisc.