A generic function to collect coefficients and summary statistics from a binlgmm object. It is used in mtable
# S3 method for binlgmm
getSummary(obj, alpha = 0.05, ...)A list with an array with coefficient estimates and a vector containing the model summary statistics.
a binlgmm object,
level of the confidence intervals,
further arguments,
For more details see package memisc.